pub struct Audiofire2Protocol;Expand description
Protocol implementation for Audiofire 2.
Diagram of internal signal flow
analog-input-1/2 ---------+-------------------------------> stream-output-1/2
|
spdif-input-1/2 ----------|----+--------------------------> stream-output-3/4
| |
v v
++==========++ ++========++
stream-input-1/2 ---> || mixer || ---> || router || ---> analog-output-1/2
stream-input-3/4 ---> || || ---> || || ---> headphone-output-1/2
stream-input-5/6 ---> || 10 x 6 || ---> || 6 x 6 || ---> spdif-output-1/2
++==========++ ++========++Trait Implementations
Sourceimpl Debug for Audiofire2Protocol
impl Debug for Audiofire2Protocol
Sourceimpl Default for Audiofire2Protocol
impl Default for Audiofire2Protocol
Sourcefn default() -> Audiofire2Protocol
fn default() -> Audiofire2Protocol
Returns the “default value” for a type. Read more
Sourceimpl EfwHardwareSpecification for Audiofire2Protocol
impl EfwHardwareSpecification for Audiofire2Protocol
Sourceconst SUPPORTED_SAMPLING_RATES: &'static [u32]
const SUPPORTED_SAMPLING_RATES: &'static [u32]
The list of supported sampling transfer frequencies.
Sourceconst SUPPORTED_SAMPLING_CLOCKS: &'static [ClkSrc]
const SUPPORTED_SAMPLING_CLOCKS: &'static [ClkSrc]
The list of supported sources of sampling clock.
Sourceconst CAPABILITIES: &'static [HwCap]
const CAPABILITIES: &'static [HwCap]
The list of hardware capabilities.
Sourceconst TX_CHANNEL_COUNTS: [usize; 3]
const TX_CHANNEL_COUNTS: [usize; 3]
The number of audio channels in transmitted isochronous stream at each rate mode.
Sourceconst RX_CHANNEL_COUNTS: [usize; 3]
const RX_CHANNEL_COUNTS: [usize; 3]
The number of audio channels in received isochronous stream at each rate mode.
Sourceconst MONITOR_SOURCE_COUNT: usize = 4usize
const MONITOR_SOURCE_COUNT: usize = 4usize
The total number of monitor inputs.
Sourceconst MONITOR_DESTINATION_COUNT: usize = 6usize
const MONITOR_DESTINATION_COUNT: usize = 6usize
The total number of monitor outputs.
Sourceconst MIDI_INPUT_COUNT: usize = 1usize
const MIDI_INPUT_COUNT: usize = 1usize
The number of MIDI input port.
Sourceconst MIDI_OUTPUT_COUNT: usize = 1usize
const MIDI_OUTPUT_COUNT: usize = 1usize
The number of MIDI output port.
const PHYS_INPUT_GROUPS: &'static [(PhysGroupType, usize)]
const PHYS_OUTPUT_GROUPS: &'static [(PhysGroupType, usize)]
Sourcefn phys_input_count() -> usize
fn phys_input_count() -> usize
The total number of physical audio inputs.
Sourcefn phys_output_count() -> usize
fn phys_output_count() -> usize
The total number of physical audio outputs.
fn create_hardware_meter() -> HwMeter
fn create_monitor_parameters() -> EfwMonitorParameters
fn create_output_parameters() -> EfwOutputParameters
fn create_playback_parameters() -> EfwPlaybackParameters
Sourceimpl EfwRxStreamMapsSpecification for Audiofire2Protocol
impl EfwRxStreamMapsSpecification for Audiofire2Protocol
const STREAM_MAPPING_RATE_TABLE: [&'static [u32]; 3] = _
fn create_rx_stream_maps() -> EfwRxStreamMaps