pub struct RipProtocol;Expand description
Protocol implementation for former model of Robot Interface Pack (RIP).
Diagram of internal signal flow
guitar-input-1 ------+
piezo-input-2 -------+---+-------------> stream-output-1/2
string-input-1/2 --------|--+----------> stream-output-5/6
string-input-3/4 --------|--|----------> stream-output-7/8
string-input-5/6 --------|--|--+-------> stream-output-7/8
| | |
v v v
++=========++
|| mixer ||
stream-input-1/2 ---> || || ---> analog-output-1/2
|| 8 x 6 ||
++=========++Trait Implementations
Sourceimpl Debug for RipProtocol
impl Debug for RipProtocol
Sourceimpl Default for RipProtocol
impl Default for RipProtocol
Sourcefn default() -> RipProtocol
fn default() -> RipProtocol
Returns the “default value” for a type. Read more
Sourceimpl EfwHardwareSpecification for RipProtocol
impl EfwHardwareSpecification for RipProtocol
Sourceconst SUPPORTED_SAMPLING_RATES: &'static [u32]
const SUPPORTED_SAMPLING_RATES: &'static [u32]
The list of supported sampling transfer frequencies.
Sourceconst SUPPORTED_SAMPLING_CLOCKS: &'static [ClkSrc]
const SUPPORTED_SAMPLING_CLOCKS: &'static [ClkSrc]
The list of supported sources of sampling clock.
Sourceconst CAPABILITIES: &'static [HwCap]
const CAPABILITIES: &'static [HwCap]
The list of hardware capabilities.
Sourceconst TX_CHANNEL_COUNTS: [usize; 3]
const TX_CHANNEL_COUNTS: [usize; 3]
The number of audio channels in transmitted isochronous stream at each rate mode.
Sourceconst RX_CHANNEL_COUNTS: [usize; 3]
const RX_CHANNEL_COUNTS: [usize; 3]
The number of audio channels in received isochronous stream at each rate mode.
Sourceconst MONITOR_SOURCE_COUNT: usize = 8usize
const MONITOR_SOURCE_COUNT: usize = 8usize
The total number of monitor inputs.
Sourceconst MONITOR_DESTINATION_COUNT: usize = 2usize
const MONITOR_DESTINATION_COUNT: usize = 2usize
The total number of monitor outputs.
Sourceconst MIDI_INPUT_COUNT: usize = 0usize
const MIDI_INPUT_COUNT: usize = 0usize
The number of MIDI input port.
Sourceconst MIDI_OUTPUT_COUNT: usize = 0usize
const MIDI_OUTPUT_COUNT: usize = 0usize
The number of MIDI output port.
const PHYS_INPUT_GROUPS: &'static [(PhysGroupType, usize)]
const PHYS_OUTPUT_GROUPS: &'static [(PhysGroupType, usize)]
Sourcefn phys_input_count() -> usize
fn phys_input_count() -> usize
The total number of physical audio inputs.
Sourcefn phys_output_count() -> usize
fn phys_output_count() -> usize
The total number of physical audio outputs.
fn create_hardware_meter() -> HwMeter
fn create_monitor_parameters() -> EfwMonitorParameters
fn create_output_parameters() -> EfwOutputParameters
fn create_playback_parameters() -> EfwPlaybackParameters
impl EfwRobotGuitarSpecification for RipProtocol